@@ -29,3 +29,14 @@ echo "GUI_OPTS=$gui_opts" >> /var/run/qubes-service-environment
 
 # 2**30
 echo 1073741824 > /sys/module/xen_gntalloc/parameters/limit
+
+# unbind Xen VGA adapter from bochs
+driver=/sys/bus/pci/drivers/bochs-drm
+if [ -e "$driver" ]; then
+    for dev in "$driver"/0000:*; do
+        [ -e "$dev" ] || continue
+        if [ "$(cat "$dev/vendor"):$(cat "$dev/device")" = "0x1234:0x1111" ]; then
+            echo "${dev##*/}" > "$driver/unbind"
+        fi
+    done
+fi
